#include <mooutils/mooglade.h>
#include <mooutils/mooi18n.h>
#include <gtk/gtk.h>

static const char _drop_xml_glade_xml[] =
"<?xml version=\"1.0\"?>"
"<glade-interface>"
"<widget class=\"GtkDialog\" id=\"Drop\">"
"<property name=\"visible\">True</property>"
"<property name=\"title\" translatable=\"yes\">Save As</property>"
"<property name=\"window_position\">GTK_WIN_POS_MOUSE</property>"
"<property name=\"type_hint\">GDK_WINDOW_TYPE_HINT_DIALOG</property>"
"<property name=\"has_separator\">False</property>"
"<child internal-child=\"vbox\">"
"<widget class=\"GtkVBox\" id=\"dialog-vbox1\">"
"<property name=\"visible\">True</property>"
"<child>"
"<widget class=\"GtkAlignment\" id=\"alignment1\">"
"<property name=\"visible\">True</property>"
"<property name=\"top_padding\">6</property>"
"<property name=\"bottom_padding\">6</property>"
"<property name=\"left_padding\">6</property>"
"<property name=\"right_padding\">6</property>"
"<child>"
"<widget class=\"GtkVBox\" id=\"vbox1\">"
"<property name=\"visible\">True</property>"
"<property name=\"spacing\">6</property>"
"<child>"
"<widget class=\"GtkLabel\" id=\"label1\">"
"<property name=\"visible\">True</property>"
"<property name=\"xalign\">0</property>"
"<property name=\"label\">Save as</property>"
"</widget>"
"<packing>"
"<property name=\"expand\">False</property>"
"<property name=\"fill\">False</property>"
"</packing>"
"</child>"
"<child>"
"<widget class=\"GtkEntry\" id=\"entry:MooEntry\">"
"<property name=\"visible\">True</property>"
"<property name=\"activates_default\">True</property>"
"</widget>"
"<packing>"
"<property name=\"expand\">False</property>"
"<property name=\"fill\">False</property>"
"<property name=\"position\">1</property>"
"</packing>"
"</child>"
"</widget>"
"</child>"
"</widget>"
"<packing>"
"<property name=\"position\">1</property>"
"</packing>"
"</child>"
"<child internal-child=\"action_area\">"
"<widget class=\"GtkHButtonBox\" id=\"dialog-action_area1\">"
"<property name=\"visible\">True</property>"
"<property name=\"layout_style\">GTK_BUTTONBOX_END</property>"
"<child>"
"<widget class=\"GtkButton\" id=\"cancelbutton1\">"
"<property name=\"visible\">True</property>"
"<property name=\"can_default\">True</property>"
"<property name=\"label\">gtk-cancel</property>"
"<property name=\"use_stock\">True</property>"
"<property name=\"response_id\">-6</property>"
"</widget>"
"</child>"
"<child>"
"<widget class=\"GtkButton\" id=\"ok_button\">"
"<property name=\"visible\">True</property>"
"<property name=\"can_default\">True</property>"
"<property name=\"has_default\">True</property>"
"<property name=\"label\">gtk-ok</property>"
"<property name=\"use_stock\">True</property>"
"<property name=\"response_id\">-5</property>"
"</widget>"
"<packing>"
"<property name=\"position\">1</property>"
"</packing>"
"</child>"
"</widget>"
"<packing>"
"<property name=\"expand\">False</property>"
"<property name=\"pack_type\">GTK_PACK_END</property>"
"</packing>"
"</child>"
"</widget>"
"</child>"
"</widget>"
"</glade-interface>"

;

typedef struct DropXml DropXml;

struct DropXml {
    MooGladeXML *xml;

    GtkDialog *Drop;
    MooEntry *entry;
    GtkButton *ok_button;

};

static void
_drop_xml_free (DropXml *xml)
{
    if (xml)
    {
        if (xml->xml)
            g_object_unref (xml->xml);
        g_free (xml);
    }
}

G_GNUC_UNUSED static DropXml *
drop_xml_get (gpointer widget)
{
    return (DropXml*) g_object_get_data (G_OBJECT (widget), "moo-generated-glade-xml");
}

static gboolean
_drop_xml_finish_build (DropXml *xml)
{
    g_return_val_if_fail(xml != NULL, FALSE);

    xml->Drop = (GtkDialog*) moo_glade_xml_get_widget (xml->xml, "Drop");
    g_return_val_if_fail (xml->Drop != NULL, FALSE);
    xml->entry = (MooEntry*) moo_glade_xml_get_widget (xml->xml, "entry:MooEntry");
    g_return_val_if_fail (xml->entry != NULL, FALSE);
    xml->ok_button = (GtkButton*) moo_glade_xml_get_widget (xml->xml, "ok_button");
    g_return_val_if_fail (xml->ok_button != NULL, FALSE);

    g_object_set_data_full (G_OBJECT (xml->Drop), "moo-generated-glade-xml",
                            xml, (GDestroyNotify) _drop_xml_free);
    return TRUE;
}

static gboolean
drop_xml_build (DropXml *xml)
{
    GError *error = NULL;
    if (!moo_glade_xml_parse_memory (xml->xml, _drop_xml_glade_xml, -1, "Drop", &error))
    {
        g_critical ("Could not parse glade xml: %s", error->message);
        g_error_free (error);
        return FALSE;
    }
    return _drop_xml_finish_build (xml);
}

static gboolean
drop_xml_fill (DropXml *xml, GtkWidget *root)
{
    GError *error = NULL;
    if (!moo_glade_xml_fill_widget (xml->xml, root, _drop_xml_glade_xml, -1, "Drop", &error))
    {
        g_critical ("Could not parse glade xml: %s", error->message);
        g_error_free (error);
        return FALSE;
    }
    return _drop_xml_finish_build (xml);
}

static DropXml *
drop_xml_new_empty (void)
{
    DropXml *xml = g_new0 (DropXml, 1);
    xml->xml = moo_glade_xml_new_empty (GETTEXT_PACKAGE);

    return xml;
}

G_GNUC_UNUSED static DropXml *
drop_xml_new (void)
{
    DropXml *xml = drop_xml_new_empty ();
    if (!drop_xml_build (xml))
    {
        _drop_xml_free (xml);
        xml = NULL;
    }
    return xml;
}

G_GNUC_UNUSED static DropXml *
drop_xml_new_with_root (GtkWidget *root)
{
    DropXml *xml = drop_xml_new_empty ();
    if (!drop_xml_fill (xml, root))
    {
        _drop_xml_free (xml);
        xml = NULL;
    }
    return xml;
}
